import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:price_and_profit/screens/profit_prediction/profit_form.dart';

class Home extends StatefulWidget {
  const Home({Key? key}) : super(key: key);

  @override
  State<Home> createState() => _HomeState();
}

class _HomeState extends State<Home> {
  Widget buildButton({
    required String title,
    required IconData icon,
    required VoidCallback onClicked,
  }) =>
      ElevatedButton(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            Icon(icon, size: 25),
            const SizedBox(width: 16),
            Text(title),
          ],
        ),
        onPressed: onClicked,
        style: ElevatedButton.styleFrom(
          minimumSize: const Size.fromHeight(45),
          primary: Color.fromARGB(255, 173, 118, 36),
          onPrimary: Colors.black54,
          textStyle: const TextStyle(
            fontSize: 18,
            fontWeight: FontWeight.bold,
          ),
        ),
      );

  final Gradient appBarGradient = LinearGradient(
    colors: [
      Color.fromARGB(255, 23, 58, 170),
      Color.fromARGB(255, 101, 74, 253),
    ],
    begin: Alignment.centerLeft,
    end: Alignment.centerRight,
  );
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        iconTheme: const IconThemeData(
          color: Colors.white,
        ),
        toolbarHeight: 100,
        backgroundColor:
            Colors.transparent, // Set the background color to transparent
        flexibleSpace: Container(
          decoration: BoxDecoration(
              gradient: appBarGradient), // Apply the gradient here
        ), //0xff809b7b
        title: Row(
          children: [
            const CircleAvatar(
              backgroundColor: Color.fromARGB(255, 173, 118, 36),
              radius: 30,
              backgroundImage: AssetImage("assets/images/mushroom.jpg"),
            ),
            const SizedBox(
              width: 20,
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: const [
                Text(
                  'Dashboard',
                  style: TextStyle(
                    fontFamily: 'Cabin',
                  ),
                ),
                Text(
                  'Home',
                  style: TextStyle(
                    fontFamily: 'Cabin',
                    fontSize: 12,
                  ),
                ),
              ],
            ),
          ],
        ),
        elevation: 0,
      ),
      backgroundColor: const Color.fromARGB(255, 23, 58, 170),
      body: Column(
        children: [
          Expanded(
            child: Container(
              padding: const EdgeInsets.symmetric(horizontal: 80),
              height: 100,
              decoration: const BoxDecoration(
                image: DecorationImage(
                  image: AssetImage("assets/images/wall2.jpg"),
                  fit: BoxFit.cover,
                ),
                color: Colors.white,
                borderRadius: BorderRadius.only(
                  topLeft: Radius.circular(30),
                  topRight: Radius.circular(30),
                ),
              ),
              child: ClipRRect(
                borderRadius: const BorderRadius.only(
                  topLeft: Radius.circular(30),
                  topRight: Radius.circular(30),
                ),
                child: Container(
                  child: Column(
                    children: [
                      Container(
                        width: 230,
                        height: 230,
                      ),
                      const SizedBox(height: 2),
                      const SizedBox(height: 15),
                      Align(
                        alignment: Alignment.center,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                          children: [
                            GestureDetector(
                              onTap: () {
                                Navigator.of(context).push(
                                  MaterialPageRoute(
                                    builder: (context) => MyForm(),
                                  ),
                                );
                              },
                              child: Card(
                                color: Color.fromARGB(206, 59, 100, 235),
                                child: Container(
                                  width: 160,
                                  height: 150,
                                  child: Column(
                                    mainAxisAlignment: MainAxisAlignment.center,
                                    children: [
                                      Icon(Icons.android, size: 50),
                                      SizedBox(height: 10),
                                      Text(
                                        'Profit And Price',
                                        textAlign: TextAlign.center,
                                      ),
                                    ],
                                  ),
                                ),
                              ),
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
